@@ -88,6 +88,16 @@ class OSDF(object):
             else:
                 raise Exception("Unable to edit node document.")
 
+    def _byteify(self, input):
+        if isinstance(input, dict):
+            return {self._byteify(key):self._byteify(value) for key,value in input.iteritems()}
+        elif isinstance(input, list):
+            return [self._byteify(element) for element in input]
+        elif isinstance(input, unicode):
+            return input.encode('utf-8')
+        else:
+            return input
+
     def get_info(self):
         """
         Retrieve's the OSDF server's information/contact document
@@ -96,6 +106,8 @@ class OSDF(object):
 
         info = json.loads( osdf_response['content'] )
 
+        info = self._byteify(info)
+
         return info
 
     def get_node(self, node_id):
@@ -119,6 +131,8 @@ class OSDF(object):
 
         data = json.loads( osdf_response['content'] )
 
+        data = self._byteify(data)
+
         return data
 
     def get_schema(self, namespace, schema_name):
@@ -144,6 +158,8 @@ class OSDF(object):
 
         schema_data = json.loads( osdf_response['content'] )
 
+        schema_data = self._byteify(schema_data)
+
         return schema_data
 
     def get_aux_schema(self, namespace, aux_schema_name):
@@ -169,6 +185,8 @@ class OSDF(object):
 
         aux_schema_data = json.loads( osdf_response['content'] )
 
+        aux_schema_data = self._byteify(aux_schema_data)
+
         return aux_schema_data
 
     def insert_node(self, json_data):
@@ -267,6 +285,8 @@ class OSDF(object):
 
         data = json.loads( osdf_response['content'] )
 
+        data = self._byteify(data)
+
         return data
 
     def query_all_pages(self, namespace, query):
